@@ -1,7 +1,7 @@
 /*****************************************************************************
- * comm.c: Handles the communication socket (linux-dvb only)
+ * comm.c: Handles the communication socket
  *****************************************************************************
- * Copyright (C) 2008 VideoLAN
+ * Copyright (C) 2008, 2015 VideoLAN
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *
@@ -17,6 +17,7 @@
 #include <unistd.h>
 #include <stdint.h>
 #include <stdbool.h>
+#include <stddef.h>
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -25,6 +26,7 @@
 #include <arpa/inet.h>
 #include <sys/un.h>
 #include <errno.h>
+#include <ev.h>
 
 #include "dvblast.h"
 #include "en50221.h"
@@ -33,7 +35,13 @@
 /*****************************************************************************
  * Local declarations
  *****************************************************************************/
-int i_comm_fd = -1;
+static int i_comm_fd = -1;
+static struct ev_io comm_watcher;
+
+/*****************************************************************************
+ * Local prototypes
+ *****************************************************************************/
+static void comm_Read(struct ev_loop *loop, struct ev_io *w, int revents);
 
 /*****************************************************************************
  * comm_Open
@@ -43,6 +51,8 @@ void comm_Open( void )
     int i_size = COMM_MAX_MSG_CHUNK;
     struct sockaddr_un sun_server;
 
+    unlink( psz_srv_socket );
+
     if ( (i_comm_fd = socket( AF_UNIX, SOCK_DGRAM, 0 )) == -1 )
     {
         msg_Err( NULL, "cannot create comm socket (%s)", strerror(errno) );
@@ -64,12 +74,15 @@ void comm_Open( void )
         i_comm_fd = -1;
         return;
     }
+
+    ev_io_init(&comm_watcher, comm_Read, i_comm_fd, EV_READ);
+    ev_io_start(event_loop, &comm_watcher);
 }
 
 /*****************************************************************************
  * comm_Read
  *****************************************************************************/
-void comm_Read( void )
+static void comm_Read(struct ev_loop *loop, struct ev_io *w, int revents)
 {
     struct sockaddr_un sun_client;
     socklen_t sun_length = sizeof(sun_client);
@@ -124,11 +137,12 @@ void comm_Read( void )
     switch ( i_command )
     {
     case CMD_RELOAD:
-        b_conf_reload = 1;
+        config_ReadFile();
         i_answer = RET_OK;
         i_answer_size = 0;
         break;
 
+#ifdef HAVE_DVB_SUPPORT
     case CMD_FRONTEND_STATUS:
         i_answer = dvb_FrontendStatus( p_answer + COMM_HEADER_SIZE,
                                        &i_answer_size );
@@ -163,9 +177,10 @@ void comm_Read( void )
     case CMD_MMI_SEND_CHOICE:
         i_answer = en50221_SendMMIObject( p_input, i_size - COMM_HEADER_SIZE );
         break;
+#endif
 
     case CMD_SHUTDOWN:
-        b_exit_now = 1;
+        ev_break(loop, EVBREAK_ALL);
         i_answer = RET_OK;
         i_answer_size = 0;
         break;
@@ -275,8 +290,8 @@ void comm_Read( void )
     uint32_t *p_size = (uint32_t *)&p_answer[4];
     *p_size = i_answer_size + COMM_HEADER_SIZE;
 
-    msg_Dbg( NULL, "answering %d to %d with size %zd", i_answer, i_command,
-             i_answer_size );
+/*    msg_Dbg( NULL, "answering %d to %d with size %zd", i_answer, i_command,
+             i_answer_size ); */
 
 #define min(a, b) (a < b ? a : b)
     ssize_t i_sended = 0;
@@ -296,3 +311,16 @@ void comm_Read( void )
     } while ( i_to_send > 0 );
 #undef min
 }
+
+/*****************************************************************************
+ * comm_Close
+ *****************************************************************************/
+void comm_Close( void )
+{
+    if (i_comm_fd > -1)
+    {
+        ev_io_stop(event_loop, &comm_watcher);
+        close(i_comm_fd);
+        unlink(psz_srv_socket);
+    }
+}
