@@ -12,11 +12,13 @@
  * http://sam.zoy.org/wtfpl/COPYING for more details.
  *****************************************************************************/
 
+#ifdef HAVE_DVB_SUPPORT
 /* DVB Card Drivers */
 #include <linux/dvb/version.h>
 #include <linux/dvb/dmx.h>
 #include <linux/dvb/frontend.h>
 #include <linux/dvb/ca.h>
+#endif
 
 #include <bitstream/mpeg/psi.h>
 
@@ -24,7 +26,7 @@
 #define COMM_BUFFER_SIZE (COMM_HEADER_SIZE + ((PSI_PRIVATE_MAX_SIZE + PSI_HEADER_SIZE) * (PSI_TABLE_MAX_SECTIONS / 2)))
 #define COMM_HEADER_MAGIC 0x49
 
-#define COMM_MAX_MSG_CHUNK 65535
+#define COMM_MAX_MSG_CHUNK 4096
 
 typedef enum {
     CMD_INVALID             = 0,
@@ -66,11 +68,13 @@ typedef enum {
     RET_HUH                 = 255,
 } ctl_cmd_answer_t;
 
+#ifdef HAVE_DVB_SUPPORT
 struct ret_frontend_status
 {
     struct dvb_frontend_info info;
     fe_status_t i_status;
-    int32_t i_ber, i_strength, i_snr;
+    uint32_t i_ber;
+    uint16_t i_strength, i_snr;
 };
 
 struct ret_mmi_status
@@ -93,6 +97,7 @@ struct cmd_mmi_send
     uint8_t i_slot;
     en50221_mmi_object_t object;
 };
+#endif
 
 struct cmd_pid_info
 {
