@@ -548,12 +548,10 @@ static int FrontendDoDiseqc(void)
                           | (fe_voltage == SEC_VOLTAGE_13 ? 0 : 2)
                           | (fe_tone == SEC_TONE_ON ? 1 : 0);
 
-        if ( i_uncommitted > 0 && i_uncommitted < 5 )
+        if ( i_uncommitted > 0 && i_uncommitted < 17 )
         {
            uncmd.msg[3] = 0xf0 /* reset bits */
-                             | ((i_uncommitted - 1) << 2)
-                             | (fe_voltage == SEC_VOLTAGE_13 ? 0 : 2)
-                             | (fe_tone == SEC_TONE_ON ? 1 : 0);
+                             | (i_uncommitted - 1);
            if( ioctl( i_frontend, FE_DISEQC_SEND_MASTER_CMD, &uncmd ) < 0 )
            {
                msg_Err( NULL, "ioctl FE_SEND_MASTER_CMD failed (%s)",
@@ -940,6 +938,27 @@ static struct dtv_property dvbt_cmdargs[] = {
     { .cmd = DTV_HIERARCHY,       .u.data = HIERARCHY_AUTO },
     { .cmd = DTV_TUNE },
 };
+
+static struct dtv_property dvbt2_cmdargs[] = {
+    { .cmd = DTV_DELIVERY_SYSTEM, .u.data = SYS_DVBT2 },
+    { .cmd = DTV_FREQUENCY,       .u.data = 0 },
+    { .cmd = DTV_MODULATION,      .u.data = QAM_AUTO },
+    { .cmd = DTV_INVERSION,       .u.data = INVERSION_AUTO },
+    { .cmd = DTV_BANDWIDTH_HZ,    .u.data = 8000000 },
+    { .cmd = DTV_CODE_RATE_HP,    .u.data = FEC_AUTO },
+    { .cmd = DTV_CODE_RATE_LP,    .u.data = FEC_AUTO },
+    { .cmd = DTV_GUARD_INTERVAL,  .u.data = GUARD_INTERVAL_AUTO },
+    { .cmd = DTV_TRANSMISSION_MODE,.u.data = TRANSMISSION_MODE_AUTO },
+    { .cmd = DTV_HIERARCHY,       .u.data = HIERARCHY_AUTO },
+    { .cmd = DTV_STREAM_ID,      .u.data = 0 },
+    { .cmd = DTV_TUNE },
+};
+
+static struct dtv_properties dvbt2_cmdseq = {
+    .num = sizeof(dvbt2_cmdargs)/sizeof(struct dtv_property),
+    .props = dvbt2_cmdargs
+};
+
 static struct dtv_properties dvbt_cmdseq = {
     .num = sizeof(dvbt_cmdargs)/sizeof(struct dtv_property),
     .props = dvbt_cmdargs
@@ -958,6 +977,31 @@ static struct dtv_properties atsc_cmdseq = {
     .props = atsc_cmdargs
 };
 
+static struct dtv_property isdbt_cmdargs[] = {
+    { .cmd = DTV_DELIVERY_SYSTEM, .u.data = SYS_ISDBT },
+    { .cmd = DTV_FREQUENCY,       .u.data = 0 },
+    { .cmd = DTV_BANDWIDTH_HZ,    .u.data = 6000000 },
+    { .cmd = DTV_INVERSION,       .u.data = INVERSION_AUTO },
+    { .cmd = DTV_ISDBT_LAYERA_FEC,    .u.data = FEC_AUTO },
+    { .cmd = DTV_ISDBT_LAYERA_MODULATION,    .u.data = QAM_AUTO },
+    { .cmd = DTV_ISDBT_LAYERA_SEGMENT_COUNT,  .u.data = 0 },
+    { .cmd = DTV_ISDBT_LAYERA_TIME_INTERLEAVING,.u.data = 0 },
+    { .cmd = DTV_ISDBT_LAYERB_FEC,    .u.data = FEC_AUTO },
+    { .cmd = DTV_ISDBT_LAYERB_MODULATION,    .u.data = QAM_AUTO },
+    { .cmd = DTV_ISDBT_LAYERB_SEGMENT_COUNT,  .u.data = 0 },
+    { .cmd = DTV_ISDBT_LAYERB_TIME_INTERLEAVING,.u.data = 0 },
+    { .cmd = DTV_ISDBT_LAYERC_FEC,    .u.data = FEC_AUTO },
+    { .cmd = DTV_ISDBT_LAYERC_MODULATION,    .u.data = QAM_AUTO },
+    { .cmd = DTV_ISDBT_LAYERC_SEGMENT_COUNT,  .u.data = 0 },
+    { .cmd = DTV_ISDBT_LAYERC_TIME_INTERLEAVING,.u.data = 0 },
+    { .cmd = DTV_TUNE },
+};
+
+static struct dtv_properties isdbt_cmdseq = {
+    .num = sizeof(isdbt_cmdargs)/sizeof(struct dtv_property),
+    .props = isdbt_cmdargs
+};
+
 #define DELSYS 0
 #define FREQUENCY 1
 #define MODULATION 2
@@ -972,6 +1016,22 @@ static struct dtv_properties atsc_cmdseq = {
 #define ROLLOFF 8
 #define MIS 9
 #define HIERARCHY 9
+#define PLP_ID 10
+
+//ISDBT
+#define ISDBT_BANDWIDTH 2
+#define ISDBT_LAYERA_FEC 4
+#define ISDBT_LAYERA_MODULATION 5
+#define ISDBT_LAYERA_SEGMENT_COUNT 6
+#define ISDBT_LAYERA_TIME_INTERLEAVING 7
+#define ISDBT_LAYERB_FEC 8
+#define ISDBT_LAYERB_MODULATION 9
+#define ISDBT_LAYERB_SEGMENT_COUNT 10
+#define ISDBT_LAYERB_TIME_INTERLEAVING 11
+#define ISDBT_LAYERC_FEC 12
+#define ISDBT_LAYERC_MODULATION 13
+#define ISDBT_LAYERC_SEGMENT_COUNT 14
+#define ISDBT_LAYERC_TIME_INTERLEAVING 15
 
 struct dtv_property pclear[] = {
     { .cmd = DTV_CLEAR },
@@ -1001,8 +1061,12 @@ FrontendGuessSystem( fe_delivery_system_t *p_systems, int i_systems )
             return SYS_DVBC_ANNEX_B;
         if ( !strcasecmp( psz_delsys, "DVBT" ) )
             return SYS_DVBT;
+        if ( !strcasecmp( psz_delsys, "DVBT2" ) )
+           return SYS_DVBT2;
         if ( !strcasecmp( psz_delsys, "ATSC" ) )
             return SYS_ATSC;
+        if ( !strcasecmp( psz_delsys, "ISDBT" ) )
+            return SYS_ISDBT;
         msg_Err( NULL, "unknown delivery system %s", psz_delsys );
         exit(1);
     }
@@ -1036,6 +1100,10 @@ FrontendGuessSystem( fe_delivery_system_t *p_systems, int i_systems )
                 if ( i_frequency > 50000000 )
                     return SYS_DVBT;
                 break;
+            case SYS_DVBT2:
+               if ( i_frequency > 50000000 && (dvb_plp_id) )
+                  return SYS_DVBT2;
+               break;
             default:
                 break;
         }
@@ -1151,7 +1219,27 @@ static void FrontendSet( bool b_init )
                  psz_modulation == NULL ? "qam_auto" : psz_modulation,
                  i_guard, i_transmission );
         break;
+    case SYS_DVBT2:
+        p = &dvbt2_cmdseq;
+        p->props[DELSYS].u.data = system;
+        p->props[FREQUENCY].u.data = i_frequency;
+        p->props[INVERSION].u.data = GetInversion();
+        if ( psz_modulation != NULL )
+            p->props[MODULATION].u.data = GetModulation();
+        p->props[BANDWIDTH].u.data = i_bandwidth * 1000000;
+        p->props[FEC_INNER].u.data = GetFECInner(info.caps);
+        p->props[FEC_LP].u.data = GetFECLP(info.caps);
+        p->props[GUARD].u.data = GetGuard();
+        p->props[TRANSMISSION].u.data = GetTransmission();
+        p->props[HIERARCHY].u.data = GetHierarchy();
+        p->props[PLP_ID].u.data = dvb_plp_id;
 
+        msg_Dbg( NULL, "tuning DVB-T2 frontend to f=%d bandwidth=%d inversion=%d fec_hp=%d fec_lp=%d hierarchy=%d modulation=%s guard=%d transmission=%d PLP_ID=%d ",
+                 i_frequency, i_bandwidth, i_inversion, i_fec, i_fec_lp,
+                 i_hierarchy,
+                 psz_modulation == NULL ? "qam_auto" : psz_modulation,
+                 i_guard, i_transmission, p->props[PLP_ID].u.data );
+        break;
 #if DVBAPI_VERSION >= 505
     case SYS_DVBC_ANNEX_A:
 #else
@@ -1217,6 +1305,28 @@ static void FrontendSet( bool b_init )
                  i_frequency, i_inversion,
                  psz_modulation == NULL ? "qam_auto" : psz_modulation );
         break;
+     case SYS_ISDBT:
+        p = &isdbt_cmdseq;
+        p->props[DELSYS].u.data = system;
+        p->props[FREQUENCY].u.data = i_frequency;
+        p->props[ISDBT_BANDWIDTH].u.data = i_bandwidth * 1000000;
+        p->props[INVERSION].u.data = GetInversion();
+        p->props[ISDBT_LAYERA_FEC].u.data = FEC_AUTO;
+        p->props[ISDBT_LAYERA_MODULATION].u.data = QAM_AUTO;
+        p->props[ISDBT_LAYERA_SEGMENT_COUNT].u.data = 0;
+        p->props[ISDBT_LAYERA_TIME_INTERLEAVING].u.data = 0;
+        p->props[ISDBT_LAYERB_FEC].u.data = FEC_AUTO;
+        p->props[ISDBT_LAYERB_MODULATION].u.data = QAM_AUTO;
+        p->props[ISDBT_LAYERB_SEGMENT_COUNT].u.data = 0;
+        p->props[ISDBT_LAYERB_TIME_INTERLEAVING].u.data = 0;
+        p->props[ISDBT_LAYERC_FEC].u.data = FEC_AUTO;
+        p->props[ISDBT_LAYERC_MODULATION].u.data = QAM_AUTO;
+        p->props[ISDBT_LAYERC_SEGMENT_COUNT].u.data = 0;
+        p->props[ISDBT_LAYERC_TIME_INTERLEAVING].u.data = 0;
+
+        msg_Dbg( NULL, "tuning ISDB-T frontend to f=%d bandwidth=%d ",
+                 i_frequency, i_bandwidth);
+        break;
 
     default:
         msg_Err( NULL, "unknown frontend type %d", info.type );
