@@ -1,7 +1,7 @@
 /*****************************************************************************
  * dvblast.h
  *****************************************************************************
- * Copyright (C) 2004, 2008-2011, 2015 VideoLAN
+ * Copyright (C) 2004, 2008-2011, 2015-2016 VideoLAN
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *          Andy Gatward <a.j.gatward@reading.ac.uk>
@@ -24,6 +24,7 @@
 #include <netdb.h>
 #include <sys/socket.h>
 #include <netinet/udp.h>
+#include <netinet/in.h>
 #include <netinet/ip.h>
 
 #include "config.h"
@@ -148,6 +149,7 @@ typedef struct output_config_t
     uint16_t *pi_pids;
     int i_nb_pids;
     uint16_t i_new_sid;
+    uint16_t i_onid;
     bool b_passthrough;
 
     /* for pidmap from config file */
@@ -180,6 +182,8 @@ typedef struct output_t
     block_t *p_eit_ts_buffer;
     uint8_t i_eit_ts_buffer_offset, i_eit_cc;
     uint16_t i_tsid;
+    /* incomplete PID (only PCR packets) */
+    uint16_t i_pcr_pid;
     // Arrays used for mapping pids.
     // newpids is indexed using the original pid
     uint16_t pi_newpids[MAX_PIDS];
@@ -238,6 +242,7 @@ extern int b_budget_mode;
 extern int b_any_type;
 extern int b_select_pmts;
 extern int b_random_tsid;
+extern int dvb_plp_id;
 extern bool b_enable_emm;
 extern bool b_enable_ecm;
 extern mtime_t i_wallclock;
