@@ -12,7 +12,7 @@
  * http://sam.zoy.org/wtfpl/COPYING for more details.
  *****************************************************************************/
 
-#include <malloc.h>
+#include <stddef.h>
 
 typedef void * access_t;
 
@@ -69,8 +69,6 @@ extern int i_ca_type;
  *****************************************************************************/
 void en50221_Init( void );
 void en50221_Reset( void );
-void en50221_Read( void );
-void en50221_Poll( void );
 void en50221_AddPMT( uint8_t *p_pmt );
 void en50221_UpdatePMT( uint8_t *p_pmt );
 void en50221_DeletePMT( uint8_t *p_pmt );
